@@ -35,10 +35,18 @@ impl Diagnostic for Problem {
     }
 
     fn source_code(&self) -> Option<&dyn SourceCode> {
-        Some(&self.commit_message)
+        if self.commit_message.is_empty() {
+            None
+        } else {
+            Some(&self.commit_message)
+        }
     }
 
     fn labels(&self) -> Option<Box<dyn Iterator<Item = LabeledSpan> + '_>> {
+        if self.commit_message.is_empty() {
+            return None;
+        }
+
         match &self.labels {
             None => None,
             Some(labels) => {
@@ -83,7 +91,7 @@ impl Problem {
         error: String,
         tip: String,
         code: Code,
-        commit_message: &CommitMessage,
+        commit_message: &CommitMessage<'_>,
         labels: Option<Vec<(String, usize, usize)>>,
         url: Option<String>,
     ) -> Self {
@@ -145,7 +153,7 @@ impl Problem {
     /// )
     /// ```
     #[must_use]
-    pub fn commit_message(&self) -> CommitMessage {
+    pub fn commit_message(&self) -> CommitMessage<'_> {
         self.commit_message.clone().into()
     }
 
